OC.L10N.register(
    "settings",
    {
    "Migration in progress. Please wait until the migration is finished" : "Migration läuft. Bitte warte, bis die Migration abgeschlossen ist",
    "Migration started …" : "Migration begonnen…",
    "Saved" : "Gespeichert",
    "Not saved" : "Nicht gespeichert",
    "Sending…" : "Senden…",
    "Email sent" : "E-Mail gesendet",
    "Private" : "Privat",
    "Don't synchronize to servers" : "Nicht mit Servern synchronisieren",
    "Trusted" : "Vertrauenswürdig",
    "Only synchronize to trusted servers" : "Nur mit vertrauenswürdigen Servern synchronisieren",
    "Public" : "Öffentlich",
    "Synchronize to trusted servers and the global and public address book" : "Mit vertrauenswürdigen Servern und dem globalen und öffentlichen Adressbuch synchronisieren",
    "Verify" : "Überprüfen",
    "Verifying …" : "Überprüfe…",
    "Unable to change password" : "Passwort konnte nicht geändert werden",
    "Very weak password" : "Sehr schwaches Passwort",
    "Weak password" : "Schwaches Passwort",
    "So-so password" : "Akzeptables Passwort",
    "Good password" : "Gutes Passwort",
    "Strong password" : "Starkes Passwort",
    "An error occurred while changing your language. Please reload the page and try again." : "Es ist ein Fehler beim Wechseln der Sprache aufgetreten. Bitte laden Sie die Seite neu und versuchen es noch einmal.",
    "An error occurred while changing your locale. Please reload the page and try again." : "Es ist ein Fehler beim Wechseln des Gebietsschemas aufgetreten. Bitte laden Sie die Seite neu und versuchen es noch einmal.",
    "Select a profile picture" : "Wählen Sie ein Profilbild",
    "Week starts on {fdow}" : "Die Woche startet am {fdow}",
    "Groups" : "Gruppen",
    "Group list is empty" : "Gruppenliste ist leer",
    "Unable to retrieve the group list" : "Gruppenliste konnte nicht abgerufen werden",
    "{actor} added you to group {group}" : "{actor} hat Sie zur Gruppe {group} hinzugefügt",
    "You added {user} to group {group}" : "Sie haben {user} zur Gruppe {group} hinzugefügt",
    "{actor} added {user} to group {group}" : "{actor} hat {user} zur Gruppe {group} hinzugefügt",
    "An administrator added you to group {group}" : "Ein Administrator hat Sie zur Gruppe {group} hinzugefügt",
    "An administrator added {user} to group {group}" : "Ein Administrator hat {user} zur Gruppe {group} hinzugefügt",
    "{actor} removed you from group {group}" : "{actor} hat Sie von der Gruppe {group} entfernt",
    "You removed {user} from group {group}" : "Sie haben {user} von der Gruppe {group} entfernt",
    "{actor} removed {user} from group {group}" : "{actor} hat {user} von der Gruppe {group} entfernt",
    "An administrator removed you from group {group}" : "Ein Administrator hat Sie von der Gruppe {group} entfernt",
    "An administrator removed {user} from group {group}" : "Ein Administrator hat {user} von der Gruppe {group} entfernt",
    "Your <strong>group memberships</strong> were modified" : "Ihre <strong>Gruppenmitgliedschaft</strong> wurde geändert",
    "{actor} changed your password" : "{actor} hat Ihr Passwort geändert",
    "You changed your password" : "Sie haben Ihr Passwort geändert",
    "Your password was reset by an administrator" : "Ihr Passwort wurde vom Administrator zurückgesetzt",
    "Your password was reset" : "Ihr Passwort wurde zurückgesetzt",
    "{actor} changed your email address" : "{actor} hat Ihre E-Mail-Adresse geändert",
    "You changed your email address" : "Sie haben Ihre E-Mail-Adresse geändert",
    "Your email address was changed by an administrator" : "Ihre E-Mail-Adresse wurde von einem Administrator geändert",
    "You created app password \"{token}\"" : "Sie haben das App-Passwort \"{token}\" erstellt",
    "You deleted app password \"{token}\"" : "Sie haben das App-Passwort \"{token}\" entfernt",
    "You renamed app password \"{token}\" to \"{newToken}\"" : "Sie haben App-Passwort \"{token}\" in \"{newToken}\" umbenannt",
    "You granted filesystem access to app password \"{token}\"" : "Sie haben Dateisystemzugriff für App-Passwort \"{token}\" erlaubt",
    "You revoked filesystem access from app password \"{token}\"" : "Sie haben Dateisystemzugriff für App-Passwort \"{token}\" widerrufen",
    "Security" : "Sicherheit",
    "You successfully logged in using two-factor authentication (%1$s)" : "Sie haben sich erfolgreich mittels Zwei-Faktor-Authentifizierung angemeldet (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "Ein Anmeldeversuch mittels Zwei-Faktor-Authentifizierung schlug fehl (%1$s)",
    "Remote wipe was started on %1$s" : "Fernlöschung wurde am %1$s gestartet",
    "Remote wipe has finished on %1$s" : "Fernlöschung wurde am %1$s abgeschlossen",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "Ihr <strong>Passwort</strong> oder Ihre <strong>E-Mail-Adresse</strong> wurde geändert",
    "Couldn't remove app." : "Die App konnte nicht entfernt werden.",
    "Couldn't update app." : "Die App konnte nicht aktualisiert werden.",
    "Wrong password" : "Falsches Passwort",
    "No user supplied" : "Kein Benutzer angegeben",
    "Authentication error" : "Authentifizierungsfehler",
    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Bitte geben Sie ein Wiederherstellungspasswort für das Administratorkonto an, da sonst alle Benutzerdaten verlorengehen.",
    "Wrong admin recovery password. Please check the password and try again." : "Falsches Wiederherstellungspasswort für das Admin-Konto. Bitte überprüfen Sie das Passwort und versuchen Sie es erneut.",
    "Backend doesn't support password change, but the user's encryption key was updated." : "Das Backend unterstützt die Passwortänderung nicht, aber das Verschlüsselungspasswort des Benutzers wurde aktualisiert.",
    "installing and updating apps via the app store or Federated Cloud Sharing" : "Das Installieren und Aktualisieren von Apps durch den App-Store oder durch Federated Cloud Sharing",
    "Federated Cloud Sharing" : "Federated-Cloud-Sharing",
    "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL verwendet eine veraltete %1$s Version (%2$s). Bitte aktualisieren Sie ihr Betriebssystem, da ansonsten Funktionen, wie z.B. %3$s, nicht zuverlässig funktionieren.",
    "Could not determine if TLS version of cURL is outdated or not because an error happened during the HTTPS request against https://nextcloud.com. Please check the nextcloud log file for more details." : "Es konnte nicht festgestellt werden, ob die TLS-Version von cURL veraltet ist oder nicht, da während der HTTPS-Anforderung an https://nextcloud.com ein Fehler aufgetreten ist. Bitte überprüfen Sie die Nextcloud-Protokolldatei für weitere Einzelheiten.",
    "Invalid SMTP password." : "Ungültiges SMTP-Passwort.",
    "Email setting test" : "Test der E-Mail-Einstellungen",
    "Well done, %s!" : "Gut gemacht, %s!",
    "If you received this email, the email configuration seems to be correct." : "Wenn Sie diese E-Mail empfangen haben, sind die E-Mail-Einstellungen korrekt.",
    "Email could not be sent. Check your mail server log" : "E-Mail konnte nicht versandt werden. Prüfen Sie Ihr E-Mail-Server-Protokoll",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Beim Senden der E-Mail ist ein Problem aufgetreten. Bitte überprüfen Sie Ihre Einstellungen. (Fehler: %s)",
    "You need to set your user email before being able to send test emails." : "Sie müssen Ihre Benutzer-E-Mail-Adresse angeben, bevor Sie Test-E-Mails versenden können.",
    "Invalid mail address" : "Ungültige E-Mail-Adresse",
    "Settings saved" : "Einstellungen gespeichert",
    "Unable to change full name" : "Der vollständige Name konnte nicht geändert werden",
    "Unable to change email address" : "E-Mail-Adresse konnte nicht geändert werden",
    "Unable to set invalid phone number" : "Ungültige Rufnummer kann nicht eingestellt werden",
    "Some account data was invalid" : "Einige Kontodaten waren ungültig",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "Um Ihr Twitter-Konto zu überprüfen, veröffentlichen Sie bitte den folgenden Tweet auf Twitter (Bitte stellen Sie sicher, dass der Tweet keinen Zeilenumbruch enthält):",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "Um Ihre Webseite zu überprüfen, speichern Sie bitte den folgenden Inhalt im Web-Wurzelverzeichnist in der Datei '.well-known/CloudIdVerificationCode.txt' (bitte stellen Sie sicher, das sich der gesamte Text in einer Zeile befindet):",
    "%1$s changed your password on %2$s." : "%1$s hat Ihr Passwort auf %2$s geändert.",
    "Your password on %s was changed." : "Ihr Passwort auf %s wurde geändert.",
    "Your password on %s was reset by an administrator." : "Ihr Passwort auf %s wurde vom Administrator zurückgesetzt.",
    "Your password on %s was reset." : "Ihr Passwort auf %s wurde zurückgesetzt",
    "Password for %1$s changed on %2$s" : "Passwort für %1$s geändert auf %2$s",
    "Password changed for %s" : "Passwort geändert für %s ",
    "If you did not request this, please contact an administrator." : "Wenn Sie das nicht angefordert haben sollten, wenden Sie sich bitte an den Administrator.",
    "Your email address on %s was changed." : "Ihre E-Mail-Adresse auf %s wurde geändert.",
    "Your email address on %s was changed by an administrator." : "Ihre E-Mail-Adresse auf %s wurde von einem Administrator geändert.",
    "Email address for %1$s changed on %2$s" : "E-Mail-Adresse für %1$s geändert auf %2$s",
    "Email address changed for %s" : "E-Mail-Adresse geändert für %s",
    "The new email address is %s" : "Die neue E-Mail-Adresse lautet %s",
    "Your %s account was created" : "Ihr %s-Konto wurde erstellt",
    "Welcome aboard" : "Willkommen an Bord",
    "Welcome aboard %s" : "Willkommen an Bord %s",
    "Welcome to your %s account, you can add, protect, and share your data." : "Willkommen zu Ihrem %s-Konto. Sie können Ihre Daten hinzufügen, schützen und teilen.",
    "Your username is: %s" : "Ihr Benutzername lautet: %s",
    "Set your password" : "Setzen Sie Ihr Passwort",
    "Go to %s" : "%s aufrufen",
    "Install Client" : "Installiere den Client",
    "Logged in user must be a subadmin" : "Der angemeldete Benutzer muss ein Administrator sein",
    "Apps" : "Apps",
    "Settings" : "Einstellungen",
    "Personal" : "Persönlich",
    "Administration" : "Verwaltung",
    "Additional settings" : "Zusätzliche Einstellungen",
    "Groupware" : "Groupware",
    "Overview" : "Übersicht",
    "Basic settings" : "Grundeinstellungen",
    "Sharing" : "Teilen",
    "Personal info" : "Persönliche Informationen",
    "Mobile & desktop" : "Mobil & Desktop",
    "Create" : "Erstellen",
    "Change" : "Ändern",
    "Delete" : "Löschen",
    "Reshare" : "Weiterteilen",
    "Unlimited" : "Unbegrenzt",
    "Verifying" : "Überprüfe",
    "A background job is pending that checks for user imported SSL certificates. Please check back later." : "Eine Hintergrundaufgabe, die nach vom Benutzer importierten SSL-Zertifikaten sucht, läuft noch. Bitte später erneut versuchen.",
    "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "Es sind einige vom Benutzer importierte SSL-Zertifikate vorhanden, die von Nextcloud 21 nicht mehr verwendet werden. Sie können über den Befehl \"occ security:certificates:import\" in der Befehlszeile importiert werden. Ihre Pfade innerhalb des Datenverzeichnisses werden unten angezeigt.",
    "The old server-side-encryption format is enabled. We recommend disabling this." : "Das alte serverseitige Verschlüsselungsformat ist aktiviert. Wir empfehlen, es zu deaktivieren.",
    "Nextcloud settings" : "Nextcloud-Einstellungen",
    "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "Zwei-Faktor-Authentifizierung kann für alle Benutzer und Gruppen erzwungen werden. Dann können Benutzer für die keine Zwei-Faktor-Authentifizierung eingerichtet ist, sich nicht am System anmelden.",
    "Enforce two-factor authentication" : "Zwei-Faktor-Authentifizierung erzwingen",
    "Limit to groups" : "Auf Gruppen beschränken",
    "Enforcement of two-factor authentication can be set for certain groups only." : "Erzwingen der Zwei-Faktor-Authentifizierung kann nur für bestimmte Gruppen eingestellt werden.",
    "Two-factor authentication is enforced for all members of the following groups." : "Zwei-Faktor-Authentifizierung wird für alle Mitglieder der folgenden Gruppen erzwungen.",
    "Enforced groups" : "Erzwungene Gruppen",
    "Two-factor authentication is not enforced for members of the following groups." : "Zwei-Faktor-Authentifizierung wird für Mitglieder der folgenden Gruppen nicht erzwungen.",
    "Excluded groups" : "Ausgeschlossene Gruppen",
    "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "Bei der Auswahl/Abwahl von Gruppen wird folgende Logik verwendet, um festzustellen, ob ein Benutzer 2FA verwenden muss: Wenn keine Gruppe ausgewählt ist, dann wird 2FA für alle Benutzer aktiviert, außer für Mitglieder der ausgenommenen Gruppen. Sind Gruppen ausgewählt, so wird 2FA für alle Mitglieder dieser Gruppen aktiviert. Ist ein Benutzer sowohl Mitglied der ausgewählten als auch der ausgenommenen Gruppe, so hat die Auswahl Vorrang und 2FA wird aktiviert. ",
    "Save changes" : "Änderungen speichern ",
    "All" : "Alle",
    "Limit app usage to groups" : "App-Verwendung auf Gruppen beschränken",
    "No results" : "Keine Ergebnisse",
    "Update to {version}" : "Aktualisieren auf {version}",
    "Remove" : "Entfernen",
    "Disable" : "Deaktivieren",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Für diese App wurde keine untere Versionsgrenze für Nextcloud gesetzt. Dies wird zukünftig als Fehler behandelt.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Für diese App wurde keine obere Versionsgrenze für Nextcloud gesetzt. Dies wird zukünftig als Fehler behandelt.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Diese App kann nicht installiert werden, weil die folgenden Abhängigkeiten nicht erfüllt sind:",
    "View in store" : "Im Store anzeigen",
    "Visit website" : "Webseite besuchen",
    "Report a bug" : "Einen technischen Fehler melden",
    "User documentation" : "Dokumentation für Benutzer",
    "Admin documentation" : "Dokumentation für Administratoren",
    "Developer documentation" : "Dokumentation für Entwickler",
    "This app is supported via your current Nextcloud subscription." : "Diese App wird von Ihrem aktuellen Nextcloud-Abonnement unterstützt.",
    "Supported" : "Unterstützt",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Vorgestellte Apps werden von und innerhalb der Nextcloud-Community entwickelt. Sie stellen zentrale Funktionen bereit und sind für den produktiven Einsatz geeignet.",
    "Featured" : "Vorgestellt",
    "Update to {update}" : "Aktualisieren auf {update}",
    "Update all" : "Alle aktualisieren",
    "Results from other categories" : "Ergebnisse aus anderen Kategorien",
    "No apps found for your version" : "Es wurden keine Apps für Ihre Version gefunden",
    "Disable all" : "Alle deaktivieren",
    "Enable all" : "Alle aktivieren",
    "_%n app has an update available_::_%n apps have an update available_" : ["Für %n App ist eine Aktualisierung verfügbar","Für %n Apps sind Aktualisierungen verfügbar"],
    "Marked for remote wipe" : "Für Fernlöschung markiert",
    "Device settings" : "Geräteeinstellungen",
    "Allow filesystem access" : "Erlaube Dateisystem-Zugriff",
    "Rename" : "Umbennen",
    "Revoke" : "Widerrufen",
    "Wipe device" : "Gerät löschen",
    "Revoking this token might prevent the wiping of your device if it hasn't started the wipe yet." : "Zurückziehen dieses Tokens könnte das Löschen von Ihrem Gerät verhindern, wenn die Löschung noch nicht gestartet wurde.",
    "Internet Explorer" : "Internet Explorer",
    "Edge" : "Edge",
    "Firefox" : "Firefox",
    "Google Chrome" : "Google Chrome",
    "Safari" : "Safari",
    "Google Chrome for Android" : "Google Chrome für Android",
    "iPhone" : "iPhone",
    "iPad" : "iPad",
    "Nextcloud iOS app" : "Nextcloud iOS-App",
    "Nextcloud Android app" : "Nextcloud Android-App",
    "Nextcloud Talk for iOS" : "Nextcloud Talk für iOS",
    "Nextcloud Talk for Android" : "Nextcloud Talk für Android",
    "Sync client - {os}" : "Sync-Client - {os}",
    "This session" : "Diese Sitzung",
    "Device" : "Gerät",
    "Last activity" : "Letzte Aktivität",
    "Devices & sessions" : "Geräte & Sitzungen",
    "Web, desktop and mobile clients currently logged in to your account." : "Aktuell in Ihrem Konto angemeldete Web-, Desktop- und Mobil-Clients.",
    "Do you really want to wipe your data from this device?" : "Möchten Sie wirklich alle Daten von diesem Gerät löschen?",
    "Confirm wipe" : "Löschen bestätigen",
    "Error while creating device token" : "Fehler beim Erstellen des Geräte-Tokens",
    "Error while updating device token scope" : "Fehler bei der Aktualisierung des Geräte-Token-Scope",
    "Error while updating device token name" : "Fehler bei der Aktualisierung des Geräte-Token-Namens",
    "Error while deleting the token" : "Fehler beim Löschen des Geräte-Tokens",
    "Error while wiping the device with the token" : "Fehler während des Löschens des Geräts mit dem Token",
    "App name" : "App-Name",
    "Create new app password" : "Neues App-Passwort erstellen",
    "Use the credentials below to configure your app or device." : "Nutzen Sie die unten angebenen Anmeldeinformationen, um ihre App oder ihr Gerät zu konfigurieren.",
    "For security reasons this password will only be shown once." : "Aus Sicherheitsgründen wird das Passwort nur einmal angezeigt.",
    "Username" : "Benutzername",
    "Password" : "Passwort",
    "Done" : "Erledigt",
    "Show QR code for mobile apps" : "QR-Code für mobile Apps anzeigen",
    "Copied!" : "Kopiert!",
    "Copy" : "Kopieren",
    "Could not copy app password. Please copy it manually." : "Das Passwort für die App konnte nicht kopiert werden. Bitte kopieren Sie es manuell.",
    "You do not have permissions to see the details of this user" : "Sie haben keine Berechtigung, um auf die Details dieses Benutzers zu sehen",
    "Add new password" : "Neues Passwort hinzufügen",
    "Add new email address" : "Neue E-Mail-Adresse hinzufügen",
    "Add user in group" : "Nutzer zur Gruppe hinzufügen",
    "Set user as admin for" : "Benutzer als Administrator setzen für",
    "Select user quota" : "Benutzerkontingent auswählen",
    "No language set" : "Keine Sprache eingestellt.",
    "Delete user" : "Benutzer löschen",
    "Wipe all devices" : "Alle Geräte löschen",
    "Disable user" : "Benutzer deaktivieren",
    "Enable user" : "Benutzer aktivieren",
    "Resend welcome email" : "Willkommens-E-Mail erneut senden",
    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "Im Falle des Verlusts des Gerätes oder des Verlassens der Organisation können mit dieser Funktion sämtliche Nextcloud-Daten von allen Geräten, die mit {userid} verbunden sind, gelöscht werden. Funktioniert nur, wenn das Gerät mit dem Internet verbunden ist.",
    "Remote wipe of devices" : "Fernlöschung von Geräten",
    "Wipe {userid}'s devices" : "Lösche {userid}s Geräte",
    "Cancel" : "Abbrechen",
    "Fully delete {userid}'s account including all their personal files, app data, etc." : "Lösche {userid}s Konto vollständig inklusive aller persönlichen Dateien, App-Daten, usw.",
    "Account deletion" : "Löschung des Kontos",
    "Delete {userid}'s account" : "Konto von {userid} löschen",
    "Welcome mail sent!" : "Willkommens-E-Mail gesendet!",
    "Edit User" : "Benutzer bearbeiten",
    "Toggle user actions menu" : "Menü für Benutzeraktionen umschalten",
    "{size} used" : "{size} verwendet",
    "Will be autogenerated" : "Wird automatisch erzeugt",
    "Display name" : "Anzeigename",
    "Email" : "E-Mail",
    "Default language" : "Standard-Sprache",
    "Add a new user" : "Neuen Benutzer hinzufügen",
    "Close" : "Schließen",
    "Group admin for" : "Gruppenadministrator für",
    "Quota" : "Kontingent",
    "Language" : "Sprache",
    "User backend" : "Benutzer-Backend",
    "Storage location" : "Speicherort",
    "Last login" : "Letzte Anmeldung",
    "No users in here" : "Keine Benutzer vorhanden",
    "Default quota" : "Standard Speicherkontingent ",
    "Common languages" : "Gängige Sprachen",
    "All languages" : "Alle Sprachen",
    "Password change is disabled because the master key is disabled" : "Das Ändern des Passwortes ist deaktiviert, da der Master-Schlüssel deaktiviert ist",
    "Passwordless authentication requires a secure connection." : "Die Anmeldung ohne Passwort erfordert eine sichere Verbindung.",
    "Add WebAuthn device" : "WebAuthn-Gerät hinzufügen",
    "Please authorize your WebAuthn device." : "Bitte autorisieren Sie Ihr WebAuthn-Gerät.",
    "Name your device" : "Gerät benennen",
    "Add" : "Hinzufügen",
    "Adding your device …" : "Fügen Sie Ihr Gerät hinzu…",
    "Server error while trying to add WebAuthn device" : "Server-Fehler beim Versuch ein WebAuthn-Gerät hinzuzufügen",
    "Server error while trying to complete WebAuthn device registration" : "Server-Fehler beim Versuch die WebAuthn-Geräte-Registrierung abzuschließen",
    "Unnamed device" : "Unbenanntes Gerät",
    "Passwordless Authentication" : "Authentifizierung ohne Passwort",
    "Set up your account for passwordless authentication following the FIDO2 standard." : "Richten Sie Ihr Konto für die Authentifizierung ohne Passwort nach dem FIDO2-Standard ein.",
    "No devices configured." : "Keine Geräte eingerichtet.",
    "The following devices are configured for your account:" : "Die folgenden Geräte sind für Ihr Konto eingerichtet:",
    "Your browser does not support WebAuthn." : "Ihr Browser unterstützt kein WebAuthn.",
    "Your apps" : "Ihre Apps",
    "Active apps" : "Aktive Apps",
    "Disabled apps" : "Deaktivierte Apps",
    "Updates" : "Aktualisierungen",
    "App bundles" : "App-Pakete",
    "Featured apps" : "Vorgestellte Apps",
    "{license}-licensed" : "{license}-Lizenziert",
    "Details" : "Details",
    "Changelog" : "Liste der Änderungen",
    "by {author}\n{license}" : "von {author}\n{license}",
    "New user" : "Neuer Benutzer",
    "Enter group name" : "Gruppenname eingeben",
    "Add group" : "Gruppe hinzufügen",
    "Everyone" : "Jeder",
    "Admins" : "Administratoren",
    "Disabled users" : "Deaktivierte Benutzer",
    "Remove group" : "Gruppe entfernen",
    "Default quota:" : "Standardkontingent:",
    "Select default quota" : "Standardkontingent auswählen",
    "Show Languages" : "Sprachen anzeigen",
    "Show last login" : "Letzte Anmeldung anzeigen",
    "Show user backend" : "Benutzer-Backend anzeigen",
    "Show storage path" : "Zeige Speicherpfad",
    "Send email to new user" : "E-Mail an neuen Benutzer senden",
    "You are about to remove the group {group}. The users will NOT be deleted." : "Sie sind dabei die Gruppe {group} zu löschen. Die Benutzer werden NICHT gelöscht.",
    "Please confirm the group removal " : "Bitte die Löschung der Gruppe bestätigen",
    "Download and enable" : "Herunterladen und aktivieren",
    "Enable" : "Aktivieren",
    "Enable untested app" : "Ungetestete App aktivieren",
    "The app will be downloaded from the app store" : "Die App wird aus dem App-Store heruntergeladen",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Diese App ist als nicht-kompatibel mit Ihrer Nextcloud-Version markiert. Wenn Sie fortfahren, so können Sie die App installieren. Bitte beachten Sie, dass die App nicht wie erwartet funktionieren könnte.",
    "Never" : "Niemals",
    "An error occured during the request. Unable to proceed." : "Es ist ein Fehler bei der Anfrage aufgetreten. Es kann nicht fortgefahren werden.",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Die App wurde aktiviert, muss aber aktualisiert werden. Sie werden in 5 Sekunden zur Aktualisierungsseite weitergeleitet.",
    "App update" : "App-Aktualisierung",
    "Error: This app can not be enabled because it makes the server unstable" : "Fehler: Diese App kann nicht aktiviert werden, da sie den Server instabil macht. ",
    "Administrator documentation" : "Dokumentation für Administratoren",
    "Documentation" : "Dokumentation",
    "Forum" : "Forum",
    "None" : "Keine",
    "Login" : "Anmelden",
    "Plain" : "Klartext",
    "NT LAN Manager" : "NT-LAN-Manager",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Email server" : "E-Mail-Server",
    "Open documentation" : "Dokumentation öffnen",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Es ist wichtig diesen Server so zu konfigurieren, dass E-Mails versandt werden können, z.B. für den Passwort-Reset und Benachrichtigungen.",
    "Send mode" : "Sendemodus",
    "Encryption" : "Verschlüsselung",
    "Sendmail mode" : "Sendmail-Modus",
    "From address" : "Absenderadresse",
    "mail" : "E-Mail",
    "Authentication method" : "Authentifizierungsmethode",
    "Authentication required" : "Authentifizierung benötigt",
    "Server address" : "Serveradresse",
    "Port" : "Port",
    "Credentials" : "Zugangsdaten",
    "SMTP Username" : "SMTP-Benutzername",
    "SMTP Password" : "SMTP-Passwort",
    "Save" : "Speichern",
    "Test email settings" : "E-Mail-Einstellungen testen",
    "Send email" : "E-Mail senden",
    "Security & setup warnings" : "Sicherheits- & Einrichtungswarnungen",
    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Für die Sicherheit und Geschwindigkeit Ihrer Installation ist es von großer Bedeutung, dass sie richtig konfiguriert ist. Um Ihnen hierbei zu helfen werden einige automatische Tests durchgeführt. Weitere Informationen finden Sie in der verlinkten Dokumentation.",
    "All checks passed." : "Alle Überprüfungen bestanden.",
    "There are some errors regarding your setup." : "Es gibt einige Fehler in Ihrer Systemkonfiguration.",
    "There are some warnings regarding your setup." : "Es gibt einige Warnungen zu Ihrer Systemkonfiguration.",
    "Checking for system and security issues." : "Prüfung auf System- und Sicherheitsprobleme.",
    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Bitte überprüfen Sie noch einmal die <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">Installationsanleitungen ↗</a> und kontrollieren Sie das <a href=\"%2$s\">Protokoll</a> auf mögliche Fehler oder Warnungen.",
    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Überprüfen Sie die Sicherheit Ihrer Nextcloud mit unserem <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">Sicherheits-Scan ↗</a>.",
    "Version" : "Version",
    "Two-Factor Authentication" : "Zwei-Faktor-Authentifizierung",
    "Server-side encryption" : "Serverseitige Verschlüsselung",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "Serverseitige Verschlüsselung ermöglicht es die auf diesen Server hochgeladenen Dateien zu verschlüsseln. Dies führt allerdings auch zu Nachteilen, wie z.B. einem Geschwindigkeitsverlust. Sie sollte deshalb nur eingeschaltet werden, wenn sie wirklich benötigt wird.",
    "Enable server-side encryption" : "Serverseitige Verschlüsselung aktivieren",
    "Please read carefully before activating server-side encryption: " : "Bitte sorgfältig lesen, bevor die serverseitige Verschlüsselung aktiviert wird:",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Wird die Verschlüsselung einmal aktiviert, so werden alle ab diesem Zeitpunkt hochgeladene Dateien verschlüsselt. Sie kann nur wieder deaktiviert werden, wenn das Verschlüsselungsmodul dies unterstützt und alle Voraussetzungen (wie das Setzen eines Wiederherstellungsschlüssels) im Vorhinein erfüllt wurden.",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Verschlüsselung alleine garantiert nicht die Systemsicherheit. Bitte lese in der Dokumentation nach, wie die Verschlüsselungs-app funktioniert und welche Anwendungsfälle unterstützt werden.",
    "Be aware that encryption always increases the file size." : "Bedenken Sie, dass durch die Verschlüsselung die Dateigröße zunimmt. ",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Es ist immer gut, regelmäßig Sicherungskopien von ihren Daten zu machen. Falls Sie die Verschlüsselung nutzen, sollten Sie auch eine Sicherung der Verschlüsselungsschlüssel zusammen mit Ihren Daten machen.",
    "This is the final warning: Do you really want to enable encryption?" : "Dies ist die letzte Warnung: Möchten Sie die Verschlüsselung wirklich aktivieren?",
    "Enable encryption" : "Verschlüsselung aktivieren",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Es wurde kein Verschlüsselungs-Modul geladen, bitte ein Verschlüsselungs-Modul im Anwendungs-Menü aktivieren.",
    "Select default encryption module:" : "Standard-Verschlüsselungs-Modul auswählen:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Sie müssen Ihre Verschlüsselungsschlüssel von der alten Verschlüsselung (ownCloud <= 8.0) zur Neuen migrieren. Bitte aktivieren Sie das \"Default Encryption Module\" und rufen Sie 'occ encryption:migrate' auf.",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Sie müssen Ihre Verschlüsselungsschlüssel von der alten Verschlüsselung (ownCloud <= 8.0) zur Neuen migrieren.",
    "Start migration" : "Migration beginnen",
    "Background jobs" : "Hintergrund-Aufgaben",
    "Last job execution ran %s. Something seems wrong." : "Letzte Aufgaben-Ausführung lief %s. Etwas scheint falsch zu sein.",
    "Some jobs haven’t been executed since %s. Please consider increasing the execution frequency." : "Einige Aufträge wurden seit %s nicht mehr ausgeführt. Bitte erwägen Sie, die Ausführungsfrequenz zu erhöhen.",
    "Some jobs didn’t execute since %s. Please consider switching to system cron." : "Einige Aufträge wurden seit %s nicht mehr ausgeführt. Bitte erwägen Sie die Umstellung auf System-Cron.",
    "Last job ran %s." : "Letzte Aufgabe ausgeführt %s",
    "Background job didn’t run yet!" : "Hintergrund-Aufgabe wurde bislang nicht ausgeführt!",
    "For optimal performance it's important to configure background jobs correctly. For bigger instances 'Cron' is the recommended setting. Please see the documentation for more information." : "Um die optimale Geschwindigkeit zu erreichen ist es wichtig, dass die Hintergrund-Aktivitäten richtig konfiguriert sind. Für größere Installationen ist 'Cron' die empfohlene Einstellung. Weitere Informationen finden Sie in der Dokumentation.",
    "Pick background job setting" : "Wähle eine Hintergrund-Aufgabeneinstellung aus",
    "Execute one task with each page loaded." : "Eine Aufgabe bei jedem Laden einer Seite ausführen.",
    "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP." : "cron.php ist bei einem Webcron-Dienst angemeldet, der cron.php alle 5 Minuten über HTTP aufruft.",
    "Use system cron service to call the cron.php file every 5 minutes." : "Den System-Cron-Dienst verwenden, um die Datei cron.php alle 5 Minuten aufzurufen.",
    "The cron.php needs to be executed by the system user \"%s\"." : "Die cron.php muss durch den Systemnutzer \"%s\" ausgeführt werden.",
    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Um dies auszuführen, wird die PHP-Posix Erweiterung benötigt. Weitere Informationen in der {linkstart}PHP-Dokumentation{linkend}. ",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Als Administrator können sie das Teilen-Verhalten feinabstimmen. Weitere Informationen finden Sie in der Dokumentation.",
    "Allow apps to use the Share API" : "Apps die Benutzung der Share-API erlauben",
    "Set default expiration date for shares" : "Legen Sie das Standardablaufdatum für Freigaben fest",
    "Expire after " : "Ablauf nach ",
    "days" : "Tagen",
    "Enforce expiration date" : "Ablaufdatum erzwingen",
    "Allow users to share via link" : "Benutzern erlauben, Inhalte über Links zu teilen",
    "Allow public uploads" : "Öffentliches Hochladen erlauben",
    "Always ask for a password" : "Immer nach einem Passwort fragen",
    "Enforce password protection" : "Passwortschutz erzwingen",
    "Set default expiration date for link shares" : "Legen Sie das Standardablaufdatum für Link-Freigaben fest",
    "Allow resharing" : "Weiterteilen erlauben",
    "Allow sharing with groups" : "Teilen mit Gruppen erlauben",
    "Restrict users to only share with users in their groups" : "Benutzer auf das Teilen innerhalb ihrer Gruppen beschränken",
    "Exclude groups from sharing" : "Gruppen von Freigaben ausschließen",
    "These groups will still be able to receive shares, but not to initiate them." : "Diese Gruppen können weiterhin Freigaben empfangen, aber selbst keine mehr initiieren.",
    "Allow username autocompletion in share dialog (if this is disabled the full username or email address needs to be entered)" : "Die Auto-Vervollständigung von Benutzernamen im Teilen-Dialog zulassen (Wenn dies deaktiviert ist, müssen der vollständige Benutzername oder die E-Mail-Adresse eingegeben werden)",
    "Restrict username autocompletion to users within the same groups" : "Automatische Vervollständigung der Benutzernamen auf Benutzer innerhalb der gleichen Gruppen beschränken",
    "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "Zeige Haftungsausschluss auf der öffentlichen Upload-Seite (Wird nur gezeigt wenn die Dateiliste nicht angezeigt wird.) ",
    "This text will be shown on the public link upload page when the file list is hidden." : "Dieser Text wird auf der öffentlichen Upload-Seite angezeigt wenn die Dateiliste nicht angezeigt wird.",
    "Default share permissions" : "Standardberechtigungen für das Teilen",
    "Reasons to use Nextcloud in your organization" : "Gründe für die Verwendung von Nextcloud in Ihrer Organisation",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Entwickelt von der {communityopen}Nextcloud Community{linkclose}, der {githubopen}Quellcode{linkclose} ist lizensiert unter {licenseopen}AGPL{linkclose}-Lizenz.",
    "Like our Facebook page" : "Liken Sie uns auf unserer Facebook-Seite",
    "Follow us on Twitter" : "Folgen Sie uns auf Twitter",
    "Follow us on Mastodon" : "Folgen Sie uns auf Mastodon",
    "Check out our blog" : "Sehen Sie sich unseren Blog an",
    "Subscribe to our newsletter" : "Abonnieren Sie unseren Newsletter",
    "Profile picture" : "Profilbild",
    "Upload new" : "Neues hochladen",
    "Select from Files" : "Aus Dateien wählen",
    "Remove image" : "Bild entfernen",
    "png or jpg, max. 20 MB" : "png oder jpg, max. 20 MB",
    "Picture provided by original account" : "Bild von Original-Konto zur Verfügung gestellt",
    "Choose as profile picture" : "Als Profilbild auswählen",
    "You are a member of the following groups:" : "Sie sind Mitglied folgender Gruppen:",
    "You are using <strong>%s</strong>" : "Sie benutzen <strong>%s</strong>",
    "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "Sie verwenden <strong>%1$s</strong> von <strong>%2$s</strong> (<strong>%3$s %%</strong>)",
    "Full name" : "Vollständiger Name",
    "No display name set" : "Kein Anzeigename angegeben",
    "Your email address" : "Ihre E-Mail-Adresse",
    "No email address set" : "Keine E-Mail-Adresse angegeben",
    "For password reset and notifications" : "Für Passwort-Wiederherstellung und Benachrichtigungen",
    "Phone number" : "Telefonnummer",
    "Your phone number" : "Ihre Telefonnummer",
    "Address" : "Adresse",
    "Your postal address" : "Ihre Postadresse",
    "Website" : "Webseite",
    "It can take up to 24 hours before the account is displayed as verified." : "Es kann bis zu 24 Stunden dauern, bis das Konto als überprüt angezeigt wird.",
    "Link https://…" : "Link https://…",
    "Twitter" : "Twitter",
    "Twitter handle @…" : "Twitter-Handle @…",
    "Help translate" : "Helfen Sie bei der Übersetzung",
    "Locale" : "Gebietsschema",
    "Current password" : "Aktuelles Passwort",
    "New password" : "Neues Passwort",
    "Change password" : "Passwort ändern",
    "Use a second factor besides your password to increase security for your account." : "Verwenden Sie neben Ihrem Passwort einen zweiten Faktor, um die Sicherheit für Ihr Konto zu erhöhen.",
    "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Wenn Sie Anwendungen von Drittanbietern verwenden, um sich mit Nextcloud zu verbinden, stellen Sie bitte sicher, dass Sie für jede Anwendung ein Anwendungspasswort erstellen und konfigurieren, bevor Sie die Zwei-Faktor-Authentifizierung aktivieren.",
    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Es ist ein Fehler aufgetreten. Bitte laden Sie ein ASCII-kodiertes PEM-Zertifikat hoch.",
    "Valid until {date}" : "Gültig bis {date}",
    "Local" : "Lokal",
    "Only visible to local users" : "Nur für lokale Benutzer sichtbar",
    "Only visible to you" : "Nur für Sie sichtbar",
    "Contacts" : "Kontakte",
    "Visible to local users and to trusted servers" : "Sichtbar für lokale Benutzer und vertrauenswürdige Server",
    "Will be synced to a global and public address book" : "Wird mit einem globalen und einem öffentlichen Adressbuch synchronisiert",
    "by" : "von",
    "{counter} apps have an update available" : "Für {counter} Apps ist ein Update erhältlich",
    "SSL Root Certificates" : "SSL-Root-Zertifikate",
    "Common Name" : "Allgemeiner Name",
    "Valid until" : "Gültig bis",
    "Issued By" : "Ausgestellt von:",
    "Valid until %s" : "Gültig bis %s",
    "Import root certificate" : "Root-Zertifikat importieren",
    "Execute one task with each page loaded" : "Eine Aufgabe bei jedem Laden einer Seite ausführen",
    "Allow username autocompletion in share dialog. If this is disabled the full username or email address needs to be entered." : "Die Auto-Vervollständigung von Benutzernamen im Teilen-Dialog erlauben. Wenn dies deaktiviert ist, müssen Benutzername oder E-Mail-Adresse vollständig eingegeben werden.",
    "Show disclaimer text on the public link upload page. (Only shown when the file list is hidden.)" : "Zeige Haftungsausschluss auf der öffentlichen Upload-Seite. (Wird nur gezeigt wenn die Dateiliste nicht angezeigt wird.) "
},
"nplurals=2; plural=(n != 1);");
